grio_bandwidth(1M)

grio_bandwidth - determines guaranteed-rate I/O device bandwidth

As shipped in IRIX 6.5.22. Last changed in IRIX 6.5.19.

NAME
     grio_bandwidth - determines guaranteed-rate I/O device bandwidth

SYNOPSIS
     grio_bandwidth -d device -s iosize [ -ruwV ] [ -t sampletime ]
     grio_bandwidth -c controller -s iosize [ -ruwV ] [ -t sampletime ] [ -x lun ]
     grio_bandwidth -R -s iosize [ -fruwV ] [ -t sampletime ] [ -x lun ]

DESCRIPTION
     grio_bandwidth is used to determine the number of I/O operations of a
     given size that can be guaranteed to be performed by a given disk device,
     RAID subsystem or SCSI controller in one second.  It creates processes
     which repeatedly issue I/O requests of the given size, and device seeks
     of random lengths, to the specified devices.  The length of time to
     complete each request is recorded and this information is used to
     determine the average number of I/O operations that were performed by the
     device per second over the sample period.  This number is degraded by 10%
     to provide an approximation of the increase in I/O response time caused
     by a heavily loaded system.  In addition, grio_bandwidth keeps track of
     the longest time to complete an I/O operation time over the sample period
     and calculates the number of such "worst case" operations that can be
     performed each second.  The system administrator can use grio_bandwidth
     to obtain the bandwidth information needed to create new entries in the
     Guaranteed Rate I/O device bandwidth information file /etc/grio_disks.

     The options to grio_bandwidth are:

     -d device
          The -d option is used to specify a single disk device. The disk name
          could be specified in the /dev/[r]dsk alias name format, or in the
          format reported back by -P, -C and -F options of the grio(1M)
          command.

     -c controller
          The -c option is used to specify a single SCSI controller name. The
          name has to be specified in the format reported back by -P, -C and
          -F options of the grio(1M) command. This is also the same format
          used in /etc/ioconfig.conf.

     -R   The -R option will cause the utility to scan for all RAID devices
          attached to the system.

     -s bytes
          The -s option is used to specify the size of the I/O operation in
          bytes. It must be specified, there is no default value.

     -t seconds
          The -t option is used to specify the length of the sample period in
          seconds.  By default the sample period has a length of 600 seconds.

     -u   If the -u option is specified, the /etc/grio_disks file will be
          automatically updated with the device bandwidth information.

     -f   The -f option can only be used when both the -R and -u options are
          used. It indicates that when creating the entries in the
          /etc/grio_disk file, the RAID controller bandwidth should be split
          evenly among all RAID luns attached to the controller. By default,
          the RAID controller bandwidth will be allocated to individual RAID
          luns on a first-come, first-served basis.

     -r -w
          The user can use the -r and -w options to specify if device read
          and/or write operations should be performed.  By default only read
          operations will be performed on the device.  Normally, both -r and
          -w should be specified so that the utility uses a mix of read and
          write operations when determining the bandwidth characteristics.  If
          it is known that on the device most Guaranteed Rate I/O rate
          guarantees will be used for performing either read or write
          operations, then the correct option may be specified to obtain a
          more accurate bandwidth characterization for the expected workload.

     -x lun
          The -x option is used to exclude particular luns from the tests.  In
          some cases, it may be possible for grio_bandwidth to assume a lun is
          a regular disk lun when it is actually a controller.  The lun should
          be specified as controller,unit,lun, for example, -x 3,2,31 will
          exclude lun 31 on unit 2 on controller 3.  More than one lun can be
          supplied with multiple -x options.

     -V   The -V option causes the utility to produce more verbose output.

     The utility will use these values to determine the bandwidth performance
     characteristics of the device.  In the case of a single disk device, the
     performance characteristics of the device will be computed.  In the case
     of a RAID device, the performance characteristics of the RAID
     controllers, as well as the RAID luns, will be computed.

NOTES
     It is important to re-run the utility each time the RAID device is
     reconfigured.  The RAID device is a complex mechanism and configuration
     changes will have performance impact.  Morover, in order to insure that
     the GRIO bandwidth rate guarantees can be met even when a RAID disk has
     failed, the bandwidth number must be computed when the device is in
     degraded mode.  When running in degraded mode (ie. one of the disk
     devices in each of the RAID luns is removed/missing), the RAID
     controllers may have to compute the data for the missing disk.  This will
     increase I/O request response time.

FILES
     /etc/grio_disks
SEE ALSO
     ggd(1M), grio(1M), grio_disks(4), grio(5), ioconfig(1M).